<?php
// Copyright (C) <2015>  <it-novum GmbH>
//
// This file is dual licensed
//
// 1.
//  This program is free software: you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation, version 3 of the License.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
// 2.
//  If you purchased an openITCOCKPIT Enterprise Edition you can use this file
//  under the terms of the openITCOCKPIT Enterprise Edition license agreement.
//  License agreement and license key will be shipped with the order
//  confirmation.

namespace AlfrescoModule\Lib\InitialDatabase;

use itnovum\openITCOCKPIT\InitialDatabase\Importer;

/**
 * Class TemplateImport
 * @package AlfrescoModule\Lib\InitialDatabase
 */
class TemplateImport extends Importer {

    public function __construct() {
        $TemplateImporter = new \App\itnovum\openITCOCKPIT\ImportTemplates\TemplateImport(
            \Cake\ORM\TableRegistry::getTableLocator()->get('Commands'),
            \Cake\ORM\TableRegistry::getTableLocator()->get('Macros'),
            \Cake\ORM\TableRegistry::getTableLocator()->get('Servicetemplates'),
            \Cake\ORM\TableRegistry::getTableLocator()->get('Hosttemplates'),
            \Cake\ORM\TableRegistry::getTableLocator()->get('Servicetemplategroups')
        );
        $TemplateImporter->import($this->getData());
    }

    public function getData() {
        return [
            'Commands'              => $this->getCommandsData(),
            'Macros'                => $this->getMacrosData(),
            'Hosttemplates'         => $this->getHosttemplatesData(),
            'Servicetemplates'      => $this->getServicetemplatesData(),
            'Servicetemplategroups' => $this->getServicetemplategroupsData()
        ];
    }

    /**
     * @return array
     */
    public function getCommandsData() {
        $data = [
            0 =>
                [
                    'name'             => 'check_nrpe',
                    'command_line'     => '$USER1$/check_nrpe -H $HOSTADDRESS$ -c $ARG1$',
                    'command_type'     => '1',
                    'human_args'       => null,
                    'uuid'             => '7c8891b3-1e58-485e-9ae2-7b2a16a8f0ad',
                    'description'      => 'Check by NRPE without command args',
                    'commandarguments' =>
                        [
                            0 =>
                                [
                                    'name'       => '$ARG1$',
                                    'human_name' => 'command',
                                ],
                        ],
                ],
            1 =>
                [
                    'name'             => 'check_alfresco_http',
                    'command_line'     => '$USER1$/check_http -H $HOSTADDRESS$ -w $ARG1$ -c $ARG2$ -u http://$HOSTADDRESS$$ARG3$ -p 8080',
                    'command_type'     => '1',
                    'human_args'       => null,
                    'uuid'             => '3681bcfb-5970-4108-bc6d-63a6cf21a1b3',
                    'description'      => 'Check command for alfresco http selection',
                    'commandarguments' =>
                        [
                            0 =>
                                [
                                    'name'       => '$ARG1$',
                                    'human_name' => 'Warning (seconds)',
                                ],
                            1 =>
                                [
                                    'name'       => '$ARG2$',
                                    'human_name' => 'Critical (seconds)',
                                ],
                            2 =>
                                [
                                    'name'       => '$ARG3$',
                                    'human_name' => 'URI',
                                ],
                        ],
                ],
            2 =>
                [
                    'name'             => 'check_alfresco_http_auth',
                    'command_line'     => '$USER1$/check_http -H $HOSTADDRESS$ -w $ARG1$ -c $ARG2$ -u http://$HOSTADDRESS$$ARG3$ -p 8080 -a $USER5$:$USER6$',
                    'command_type'     => '1',
                    'human_args'       => null,
                    'uuid'             => '1f2ec45f-5375-4d92-a4c7-6f0bf38e8eab',
                    'description'      => 'Check command for alfresco http selection with authentification',
                    'commandarguments' =>
                        [
                            0 =>
                                [
                                    'name'       => '$ARG1$',
                                    'human_name' => 'Warning (seconds)',
                                ],
                            1 =>
                                [
                                    'name'       => '$ARG2$',
                                    'human_name' => 'Critical (seconds)',
                                ],
                            2 =>
                                [
                                    'name'       => '$ARG3$',
                                    'human_name' => 'URI',
                                ],
                        ],
                ],
            3 =>
                [
                    'name'             => 'check_alfresco_https',
                    'command_line'     => '$USER1$/check_http -H $HOSTADDRESS$ -w $ARG1$ -c $ARG2$ -u http://$HOSTADDRESS$$ARG3$ -p 8080 -S',
                    'command_type'     => '1',
                    'human_args'       => null,
                    'uuid'             => '89580552-5084-49ca-b901-a8f0d3795338',
                    'description'      => 'Check command for alfresco https selection',
                    'commandarguments' =>
                        [
                            0 =>
                                [
                                    'name'       => '$ARG1$',
                                    'human_name' => 'Warning (seconds)',
                                ],
                            1 =>
                                [
                                    'name'       => '$ARG2$',
                                    'human_name' => 'Critical (seconds)',
                                ],
                            2 =>
                                [
                                    'name'       => '$ARG3$',
                                    'human_name' => 'URI',
                                ],
                        ],
                ],
            4 =>
                [
                    'name'             => 'check_alfresco_https_auth',
                    'command_line'     => '$USER1$/check_http -H $HOSTADDRESS$ -w $ARG1$ -c $ARG2$ -u http://$HOSTADDRESS$$ARG3$ -p 8080 -a $USER5$:$USER6$ -S',
                    'command_type'     => '1',
                    'human_args'       => null,
                    'uuid'             => '919147f6-646b-47fd-be97-9745c0103f8a',
                    'description'      => 'Check command for alfresco https selection with authentification',
                    'commandarguments' =>
                        [
                            0 =>
                                [
                                    'name'       => '$ARG1$',
                                    'human_name' => 'Warning (seconds)',
                                ],
                            1 =>
                                [
                                    'name'       => '$ARG2$',
                                    'human_name' => 'Critical (seconds)',
                                ],
                            2 =>
                                [
                                    'name'       => '$ARG3$',
                                    'human_name' => 'URI',
                                ],
                        ],
                ],
            5 =>
                [
                    'name'             => 'check_nrpe_alfresco',
                    'command_line'     => '$USER1$/check_nrpe -H $HOSTADDRESS$ -c check_alfresco -a \\\'-U service:jmx:rmi:///jndi/rmi://$HOSTADDRESS$:50500/alfresco/jmxrmi -u $USER7$ -p $USER8$ $ARG1$\\\'',
                    'command_type'     => '1',
                    'human_args'       => null,
                    'uuid'             => '567d8c9b-4c2f-4b04-92aa-a726f134f227',
                    'description'      => 'Check by NRPE with arguments and alfresco jmx selection',
                    'commandarguments' =>
                        [
                            0 =>
                                [
                                    'name'       => '$ARG1$',
                                    'human_name' => 'command',
                                ],
                        ],
                ],
        ];
        return $data;
    }

    /**
     * @return array
     */
    public function getMacrosData() {
        $data = [
            0 =>
                [
                    'name'        => '$USER5$',
                    'value'       => 'Username',
                    'description' => 'Alfresco User Frontend',
                    'password'    => '0',
                    'created'     => '2017-07-06 11:03:42',
                    'modified'    => '2017-07-21 15:06:32',
                ],
            1 =>
                [
                    'name'        => '$USER6$',
                    'value'       => 'Password',
                    'description' => 'Alfresco Password Frontend',
                    'password'    => '0',
                    'created'     => '2017-07-06 11:03:42',
                    'modified'    => '2017-07-21 15:06:32',
                ],
            2 =>
                [
                    'name'        => '$USER7$',
                    'value'       => 'Username',
                    'description' => 'Alfresco User JMX',
                    'password'    => '0',
                    'created'     => '2017-07-06 11:03:42',
                    'modified'    => '2017-07-21 15:06:32',
                ],
            3 =>
                [
                    'name'        => '$USER8$',
                    'value'       => 'Password',
                    'description' => 'Alfresco Password JMX',
                    'password'    => '1',
                    'created'     => '2017-07-06 11:03:42',
                    'modified'    => '2017-07-21 15:06:32',
                ],
        ];
        return $data;
    }

    /**
     * @return array
     */
    public function getHosttemplatesData() {
        $data = [
            /*
            [
                'id'                                => '2',
                'uuid'                              => 'd2f712ef-fc7e-4004-9bdc-8c819f00fff',
                'name'                              => 'My Hosttemplate',
                'description'                       => '',
                'hosttemplatetype_id'               => '1',
                'command_id'                        => 'bc922eb4-84ad-44cc-9dff-43a464097753',
                ...
            ],
            [
                'id'                                => '3',
                'uuid'                              => '82e7245a-f1be-41cd-b074-ff88681f7fff',
                'name'                              => 'Another Hosttemplate',
                'description'                       => '',
                'hosttemplatetype_id'               => '1',
                'command_id'                        => 'bc922eb4-84ad-44cc-9dff-43a464097753',
                ...
            ]
            */
        ];
        return $data;
    }

    /**
     * @return array
     */
    public function getServicetemplatesData() {
        $data = [
            0  =>
                [
                    'uuid'                                      => '158b8ebf-2d36-4c78-988f-3af11302a0e6',
                    'template_name'                             => 'ALFRESCO_URI_ALFRESCO	',
                    'name'                                      => 'ALFRESCO_URI_ALFRESCO',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => 'Check the http request for <hostname>/alfressco',
                    'command_id'                                => '3681bcfb-5970-4108-bc6d-63a6cf21a1b3',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => '0',
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '0',
                    'notify_on_warning'                         => '0',
                    'notify_on_unknown'                         => '0',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => null,
                    'passive_checks_enabled'                    => '0',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => null,
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2017-07-06 11:45:57',
                    'modified'                                  => '2017-07-06 11:45:57',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => '1',
                                ],
                            1 =>
                                [
                                    'commandargument_id' => '$ARG2$',
                                    'value'              => '1',
                                ],
                            2 =>
                                [
                                    'commandargument_id' => '$ARG3$',
                                    'value'              => '/alfresco',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            1  =>
                [
                    'uuid'                                      => '2de1eb3a-9fd0-4a9f-9c80-4f1d7068027a',
                    'template_name'                             => 'ALFRESCO_URI_SHARE',
                    'name'                                      => 'ALFRESCO_URI_SHARE',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => 'Check the http request for <hostname>/share',
                    'command_id'                                => '3681bcfb-5970-4108-bc6d-63a6cf21a1b3',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => '0',
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '0',
                    'notify_on_warning'                         => '0',
                    'notify_on_unknown'                         => '0',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => null,
                    'passive_checks_enabled'                    => '0',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2017-07-06 11:49:30',
                    'modified'                                  => '2017-07-06 11:49:51',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => '1',
                                ],
                            1 =>
                                [
                                    'commandargument_id' => '$ARG2$',
                                    'value'              => '1',
                                ],
                            2 =>
                                [
                                    'commandargument_id' => '$ARG3$',
                                    'value'              => '/share',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            2  =>
                [
                    'uuid'                                      => '403839b9-d0b5-483b-b3b6-557829d131cf',
                    'template_name'                             => 'ALFRESCO_URI_AOS_SSL',
                    'name'                                      => 'ALFRESCO_URI_AOS_SSL',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => 'Check the https request for <hostname>/alfresco/aos',
                    'command_id'                                => '919147f6-646b-47fd-be97-9745c0103f8a',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => '0',
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '0',
                    'notify_on_warning'                         => '0',
                    'notify_on_unknown'                         => '0',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => null,
                    'passive_checks_enabled'                    => '0',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2017-07-06 11:50:22',
                    'modified'                                  => '2017-07-06 11:52:58',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => '1',
                                ],
                            1 =>
                                [
                                    'commandargument_id' => '$ARG2$',
                                    'value'              => '2',
                                ],
                            2 =>
                                [
                                    'commandargument_id' => '$ARG3$',
                                    'value'              => '/alfresco/aos',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            3  =>
                [
                    'uuid'                                      => 'bf523dda-1d74-4030-b393-6f02fdac069d',
                    'template_name'                             => 'ALFRESCO_URI_WEBDAV',
                    'name'                                      => 'ALFRESCO_URI_WEBDAV',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => 'Check the http request for <hostname>/alfresco/webdav',
                    'command_id'                                => '1f2ec45f-5375-4d92-a4c7-6f0bf38e8eab',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => '0',
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '0',
                    'notify_on_warning'                         => '0',
                    'notify_on_unknown'                         => '0',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => null,
                    'passive_checks_enabled'                    => '0',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2017-07-06 11:51:25',
                    'modified'                                  => '2017-07-06 16:22:15',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => '1',
                                ],
                            1 =>
                                [
                                    'commandargument_id' => '$ARG2$',
                                    'value'              => '2',
                                ],
                            2 =>
                                [
                                    'commandargument_id' => '$ARG3$',
                                    'value'              => '/alfresco/webdav',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            4  =>
                [
                    'uuid'                                      => 'c7413eab-5ba7-4cdf-80b4-1b7a8682042d',
                    'template_name'                             => 'ALFRESCO_URI_ALFRESCO_SSL',
                    'name'                                      => 'ALFRESCO_URI_ALFRESCO_SSL',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => 'Check the https request for <hostname>/alfressco',
                    'command_id'                                => '89580552-5084-49ca-b901-a8f0d3795338',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => '0',
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '0',
                    'notify_on_warning'                         => '0',
                    'notify_on_unknown'                         => '0',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => null,
                    'passive_checks_enabled'                    => '0',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2017-07-06 11:52:10',
                    'modified'                                  => '2017-07-06 11:52:27',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => '1',
                                ],
                            1 =>
                                [
                                    'commandargument_id' => '$ARG2$',
                                    'value'              => '2',
                                ],
                            2 =>
                                [
                                    'commandargument_id' => '$ARG3$',
                                    'value'              => '/alfresco',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            5  =>
                [
                    'uuid'                                      => 'b9744a35-2414-4dac-a3df-20eb4c04a018',
                    'template_name'                             => 'ALFRESCO_URI_AOS',
                    'name'                                      => 'ALFRESCO_URI_AOS',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => 'Check the http request for <hostname>/alfresco/aos',
                    'command_id'                                => '1f2ec45f-5375-4d92-a4c7-6f0bf38e8eab',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => '0',
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '0',
                    'notify_on_warning'                         => '0',
                    'notify_on_unknown'                         => '0',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => null,
                    'passive_checks_enabled'                    => '0',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2017-07-06 11:53:18',
                    'modified'                                  => '2017-07-06 11:53:35',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => '1',
                                ],
                            1 =>
                                [
                                    'commandargument_id' => '$ARG2$',
                                    'value'              => '2',
                                ],
                            2 =>
                                [
                                    'commandargument_id' => '$ARG3$',
                                    'value'              => '/alfresco/aos',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            6  =>
                [
                    'uuid'                                      => '01d501d8-719f-49b2-af88-67c7e3ad2f0e',
                    'template_name'                             => 'ALFRESCO_URI_SHARE_SSL',
                    'name'                                      => 'ALFRESCO_URI_SHARE_SSL',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => 'Check the https request for <hostname>/share',
                    'command_id'                                => '89580552-5084-49ca-b901-a8f0d3795338',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => '0',
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '0',
                    'notify_on_warning'                         => '0',
                    'notify_on_unknown'                         => '0',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => null,
                    'passive_checks_enabled'                    => '0',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2017-07-06 11:54:01',
                    'modified'                                  => '2017-07-06 11:54:15',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => '1',
                                ],
                            1 =>
                                [
                                    'commandargument_id' => '$ARG2$',
                                    'value'              => '2',
                                ],
                            2 =>
                                [
                                    'commandargument_id' => '$ARG3$',
                                    'value'              => '/share',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            7  =>
                [
                    'uuid'                                      => 'abc2afb4-124b-4f16-9821-947e9ffb4091',
                    'template_name'                             => 'ALFRESCO_URI_WEBDAV_SSL',
                    'name'                                      => 'ALFRESCO_URI_WEBDAV_SSL',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => 'Check the https request for <hostname>/alfresco/webdav',
                    'command_id'                                => '919147f6-646b-47fd-be97-9745c0103f8a',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => '0',
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '0',
                    'notify_on_warning'                         => '0',
                    'notify_on_unknown'                         => '0',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => null,
                    'passive_checks_enabled'                    => '0',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2017-07-06 11:54:29',
                    'modified'                                  => '2017-07-06 16:22:37',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => '1',
                                ],
                            1 =>
                                [
                                    'commandargument_id' => '$ARG2$',
                                    'value'              => '2',
                                ],
                            2 =>
                                [
                                    'commandargument_id' => '$ARG3$',
                                    'value'              => '/alfresco/webdav',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            8  =>
                [
                    'uuid'                                      => '79b6214d-1bc3-446e-b05c-65492e41576d',
                    'template_name'                             => 'ALFRESCO_CONNECTION_POOL',
                    'name'                                      => 'ALFRESCO_CONNECTION_POOL',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => 'Check the alfresco connection pool',
                    'command_id'                                => '567d8c9b-4c2f-4b04-92aa-a726f134f227',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => '0',
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '0',
                    'notify_on_warning'                         => '0',
                    'notify_on_unknown'                         => '0',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => null,
                    'passive_checks_enabled'                    => '0',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => null,
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2017-07-06 14:21:49',
                    'modified'                                  => '2017-07-06 14:21:49',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => '-O Alfresco:Name=ConnectionPool -A NumActive -w 100000000 -c 200000000',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            9  =>
                [
                    'uuid'                                      => '59b9dab8-2070-438b-925f-e106183815ec',
                    'template_name'                             => 'ALFRESCO_CONTENT_SERVICES',
                    'name'                                      => 'ALFRESCO_CONTENT_SERVICES',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => 'Check the alfresco content services',
                    'command_id'                                => '7c8891b3-1e58-485e-9ae2-7b2a16a8f0ad',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => '0',
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '0',
                    'notify_on_warning'                         => '0',
                    'notify_on_unknown'                         => '0',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => null,
                    'passive_checks_enabled'                    => '0',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => null,
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2017-07-06 14:23:10',
                    'modified'                                  => '2017-07-06 14:23:10',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => 'alfresco_content_services',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            10 =>
                [
                    'uuid'                                      => 'bdca56b5-993b-46d8-bb30-eec1415df102',
                    'template_name'                             => 'ALFRESCO_CONTENT_STORE_FREE',
                    'name'                                      => 'ALFRESCO_CONTENT_STORE_FREE',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => 'Check the alfresco free content store',
                    'command_id'                                => '567d8c9b-4c2f-4b04-92aa-a726f134f227',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => '0',
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '0',
                    'notify_on_warning'                         => '0',
                    'notify_on_unknown'                         => '0',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => null,
                    'passive_checks_enabled'                    => '0',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2017-07-06 14:24:08',
                    'modified'                                  => '2017-07-06 14:24:46',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => '-O Alfresco:Name=ContentStore,Type=org.alfresco.repo.content.filestore.FileContentStore,Root=/opt/alfresco-content-services/alf_data/contentstore -A SpaceFree -w 2000000000000 -c 3000000000000',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            11 =>
                [
                    'uuid'                                      => 'ed209128-1777-4513-9fa5-02d237871e11',
                    'template_name'                             => 'ALFRESCO_HEAP_USAGE',
                    'name'                                      => 'ALFRESCO_HEAP_USAGE',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => 'Check the alfresco heap usage',
                    'command_id'                                => '567d8c9b-4c2f-4b04-92aa-a726f134f227',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => '0',
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '0',
                    'notify_on_warning'                         => '0',
                    'notify_on_unknown'                         => '0',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => null,
                    'passive_checks_enabled'                    => '0',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2017-07-06 14:31:20',
                    'modified'                                  => '2017-07-06 14:31:51',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => '-O java.lang:type=Memory -A HeapMemoryUsage -K used -w 750000000 -c 800000000',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            12 =>
                [
                    'uuid'                                      => 'b693825e-6702-4dce-a440-ad60f0658b98',
                    'template_name'                             => 'ALFRESCO_LICENCE_DAY',
                    'name'                                      => 'ALFRESCO_LICENCE_DAY',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => 'Check the alfresco licence day\\\'s left',
                    'command_id'                                => '567d8c9b-4c2f-4b04-92aa-a726f134f227',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => '0',
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '0',
                    'notify_on_warning'                         => '0',
                    'notify_on_unknown'                         => '0',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => null,
                    'passive_checks_enabled'                    => '0',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2017-07-06 14:38:18',
                    'modified'                                  => '2017-07-06 14:38:36',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => '-O Alfresco:Name=License -A RemainingDays  -w 60 -c 30',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            13 =>
                [
                    'uuid'                                      => '99a4e5f3-f7a4-408b-8f47-9d93fe6474d1',
                    'template_name'                             => 'ALFRESCO_NUMBER_DOCUMENTS',
                    'name'                                      => 'ALFRESCO_NUMBER_DOCUMENTS',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => 'Check the alfresco number of stored documents',
                    'command_id'                                => '567d8c9b-4c2f-4b04-92aa-a726f134f227',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => '0',
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '0',
                    'notify_on_warning'                         => '0',
                    'notify_on_unknown'                         => '0',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => null,
                    'passive_checks_enabled'                    => '0',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2017-07-06 14:39:22',
                    'modified'                                  => '2017-07-06 14:41:17',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => '-O Alfresco:Name=SolrIndexes,Core=alfresco -A NumDocuments -w 90000000 -c 100000000',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            14 =>
                [
                    'uuid'                                      => '597c902f-05eb-4778-a704-17fff946409c',
                    'template_name'                             => 'ALFRESCO_NUMBER_DOCUMENTS_ARCHIVE',
                    'name'                                      => 'ALFRESCO_NUMBER_DOCUMENTS_ARCHIVE',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => 'Check the alfresco number of stored archive documents',
                    'command_id'                                => '567d8c9b-4c2f-4b04-92aa-a726f134f227',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => '0',
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '0',
                    'notify_on_warning'                         => '0',
                    'notify_on_unknown'                         => '0',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => null,
                    'passive_checks_enabled'                    => '0',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2017-07-06 14:41:46',
                    'modified'                                  => '2017-07-06 14:42:49',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => '-O Alfresco:Name=SolrIndexes,Core=archive -A NumDocuments -w 90000000 -c 100000000',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            15 =>
                [
                    'uuid'                                      => '047073c4-8193-4273-ad2f-11c9136d8fe2',
                    'template_name'                             => 'ALFRESCO_REPO_CONNECTED_USER',
                    'name'                                      => 'ALFRESCO_REPO_CONNECTED_USER',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => 'Check the alfresco number of connected repo user',
                    'command_id'                                => '567d8c9b-4c2f-4b04-92aa-a726f134f227',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => '0',
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '0',
                    'notify_on_warning'                         => '0',
                    'notify_on_unknown'                         => '0',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => null,
                    'passive_checks_enabled'                    => '0',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2017-07-06 14:43:23',
                    'modified'                                  => '2017-07-06 14:43:45',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => '-O Alfresco:Name=RepoServerMgmt -A UserCountAll -w 100000000 -c 200000000',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            16 =>
                [
                    'uuid'                                      => 'cede910f-e96a-47a1-a331-a8720db91c89',
                    'template_name'                             => 'ALFRESCO_REPO_SESSION',
                    'name'                                      => 'ALFRESCO_REPO_SESSION',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => 'Check the alfresco number of repo session\\\'s',
                    'command_id'                                => '567d8c9b-4c2f-4b04-92aa-a726f134f227',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => '0',
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '0',
                    'notify_on_warning'                         => '0',
                    'notify_on_unknown'                         => '0',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => null,
                    'passive_checks_enabled'                    => '0',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2017-07-06 14:45:08',
                    'modified'                                  => '2017-07-06 14:46:11',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => '-O Alfresco:Name=RepoServerMgmt -A TicketCountAll -w 100000000 -c 200000000',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            17 =>
                [
                    'uuid'                                      => '125e915e-6014-4945-bd18-5e5b8f8ecbf1',
                    'template_name'                             => 'ALFRESCO_TASK_INSTANCE',
                    'name'                                      => 'ALFRESCO_TASK_INSTANCE',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => 'Check the alfresco instance task\\\'s',
                    'command_id'                                => '567d8c9b-4c2f-4b04-92aa-a726f134f227',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => '0',
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '0',
                    'notify_on_warning'                         => '0',
                    'notify_on_unknown'                         => '0',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => null,
                    'passive_checks_enabled'                    => '0',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2017-07-06 14:47:27',
                    'modified'                                  => '2017-07-06 14:49:46',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => '-O Alfresco:Name=WorkflowInformation -A NumberOfActivitiTaskInstances -w 20 -c 30',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            18 =>
                [
                    'uuid'                                      => '00762cca-2d70-41cd-b966-1c8e5c4b67ab',
                    'template_name'                             => 'ALFRESCO_THREAD_COUNT',
                    'name'                                      => 'ALFRESCO_THREAD_COUNT',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => 'Check the alfresco thread count',
                    'command_id'                                => '567d8c9b-4c2f-4b04-92aa-a726f134f227',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => '0',
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '0',
                    'notify_on_warning'                         => '0',
                    'notify_on_unknown'                         => '0',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => null,
                    'passive_checks_enabled'                    => '0',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2017-07-06 14:50:45',
                    'modified'                                  => '2017-07-06 14:51:37',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => '-O java.lang:type=Threading -A ThreadCount -w 5000 -c 10000',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            19 =>
                [
                    'uuid'                                      => 'fbef3afc-97ff-4856-a327-35c08b71c633',
                    'template_name'                             => 'ALFRESCO_TOTAL_USER',
                    'name'                                      => 'ALFRESCO_TOTAL_USER',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => 'Check the alfresco total user',
                    'command_id'                                => '567d8c9b-4c2f-4b04-92aa-a726f134f227',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => '0',
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '0',
                    'notify_on_warning'                         => '0',
                    'notify_on_unknown'                         => '0',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => null,
                    'passive_checks_enabled'                    => '0',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2017-07-06 14:52:13',
                    'modified'                                  => '2017-07-06 14:52:25',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => '-O Alfresco:Name=Authority -A NumberOfUsers -w 800 -c 1000',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            20 =>
                [
                    'uuid'                                      => '9485b87d-8c8e-4890-821a-71db5423fdb5',
                    'template_name'                             => 'ALFRESCO_WORKFLOW_INSTANCE',
                    'name'                                      => 'ALFRESCO_WORKFLOW_INSTANCE',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '1',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => 'Check the alfresco instance workflow',
                    'command_id'                                => '567d8c9b-4c2f-4b04-92aa-a726f134f227',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => '0',
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '0',
                    'notify_on_warning'                         => '0',
                    'notify_on_unknown'                         => '0',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => null,
                    'passive_checks_enabled'                    => '0',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '1',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2017-07-06 14:52:59',
                    'modified'                                  => '2017-07-06 14:53:12',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => '-O Alfresco:Name=WorkflowInformation -A NumberOfActivitiWorkflowInstances -w 20 -c 30',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
            21 =>
                [
                    'uuid'                                      => 'e453767c-b216-4b17-a012-9bc037d7da49',
                    'template_name'                             => 'OITC_AGENT_ALFRESCO',
                    'name'                                      => 'Alfresco check',
                    'container_id'                              => '1',
                    'servicetemplatetype_id'                    => '16',
                    'check_period_id'                           => '1',
                    'notify_period_id'                          => '1',
                    'description'                               => '',
                    'command_id'                                => '0d2e47c7-d584-4a4a-9a6c-1a1ff0f9365c',
                    'check_command_args'                        => '',
                    'checkcommand_info'                         => '',
                    'eventhandler_command_id'                   => '0',
                    'timeperiod_id'                             => '0',
                    'check_interval'                            => '300',
                    'retry_interval'                            => '60',
                    'max_check_attempts'                        => '3',
                    'first_notification_delay'                  => '0',
                    'notification_interval'                     => '7200',
                    'notify_on_warning'                         => '1',
                    'notify_on_unknown'                         => '1',
                    'notify_on_critical'                        => '1',
                    'notify_on_recovery'                        => '1',
                    'notify_on_flapping'                        => '0',
                    'notify_on_downtime'                        => '0',
                    'flap_detection_enabled'                    => '0',
                    'flap_detection_on_ok'                      => '0',
                    'flap_detection_on_warning'                 => '0',
                    'flap_detection_on_unknown'                 => '0',
                    'flap_detection_on_critical'                => '0',
                    'low_flap_threshold'                        => '0',
                    'high_flap_threshold'                       => '0',
                    'process_performance_data'                  => '1',
                    'freshness_checks_enabled'                  => '0',
                    'freshness_threshold'                       => null,
                    'passive_checks_enabled'                    => '1',
                    'event_handler_enabled'                     => '0',
                    'active_checks_enabled'                     => '0',
                    'retain_status_information'                 => '0',
                    'retain_nonstatus_information'              => '0',
                    'notifications_enabled'                     => '1',
                    'notes'                                     => '',
                    'priority'                                  => '1',
                    'tags'                                      => '',
                    'service_url'                               => '',
                    'is_volatile'                               => '0',
                    'check_freshness'                           => '0',
                    'created'                                   => '2020-06-10 14:20:06',
                    'modified'                                  => '2020-06-10 14:20:06',
                    'servicetemplateeventcommandargumentvalues' =>
                        [
                        ],
                    'servicetemplatecommandargumentvalues'      =>
                        [
                            0 =>
                                [
                                    'commandargument_id' => '$ARG1$',
                                    'value'              => '0',
                                ],
                            1 =>
                                [
                                    'commandargument_id' => '$ARG2$',
                                    'value'              => '0',
                                ],
                            2 =>
                                [
                                    'commandargument_id' => '$ARG3$',
                                    'value'              => 'Alfresco check name',
                                ],
                        ],
                    'customvariables'                           =>
                        [
                        ],
                    'servicegroups'                             =>
                        [
                        ],
                    'contactgroups'                             =>
                        [
                        ],
                    'contacts'                                  =>
                        [
                        ],
                ],
        ];
        return $data;
    }

    public function getServicetemplategroupsData() {
        $data = [
            0 =>
                [
                    'uuid'             => '7efdd57a-5df7-4abf-9849-41d62062f5c4',
                    'description'      => 'Alfresco Frontend Monitoring checks (http)',
                    'servicetemplates' =>
                        [
                            0 =>
                                [
                                    'id'   => '158b8ebf-2d36-4c78-988f-3af11302a0e6',
                                    'uuid' => '158b8ebf-2d36-4c78-988f-3af11302a0e6',
                                ],
                            1 =>
                                [
                                    'id'   => 'b9744a35-2414-4dac-a3df-20eb4c04a018',
                                    'uuid' => 'b9744a35-2414-4dac-a3df-20eb4c04a018',
                                ],
                            2 =>
                                [
                                    'id'   => '2de1eb3a-9fd0-4a9f-9c80-4f1d7068027a',
                                    'uuid' => '2de1eb3a-9fd0-4a9f-9c80-4f1d7068027a',
                                ],
                            3 =>
                                [
                                    'id'   => 'bf523dda-1d74-4030-b393-6f02fdac069d',
                                    'uuid' => 'bf523dda-1d74-4030-b393-6f02fdac069d',
                                ],
                        ],
                    'container'        =>
                        [
                            'name'             => 'Alfresco Frontend Monitoring',
                            'parent_id'        => 1,
                            'containertype_id' => '9',
                        ],
                ],
            1 =>
                [
                    'uuid'             => '4029598e-76f3-4632-9d8f-33b5e36a51db',
                    'description'      => 'Alfresco Frontend Monitoring checks with SSL(https)',
                    'servicetemplates' =>
                        [
                            0 =>
                                [
                                    'id'   => 'c7413eab-5ba7-4cdf-80b4-1b7a8682042d',
                                    'uuid' => 'c7413eab-5ba7-4cdf-80b4-1b7a8682042d',
                                ],
                            1 =>
                                [
                                    'id'   => '403839b9-d0b5-483b-b3b6-557829d131cf',
                                    'uuid' => '403839b9-d0b5-483b-b3b6-557829d131cf',
                                ],
                            2 =>
                                [
                                    'id'   => '01d501d8-719f-49b2-af88-67c7e3ad2f0e',
                                    'uuid' => '01d501d8-719f-49b2-af88-67c7e3ad2f0e',
                                ],
                            3 =>
                                [
                                    'id'   => 'abc2afb4-124b-4f16-9821-947e9ffb4091',
                                    'uuid' => 'abc2afb4-124b-4f16-9821-947e9ffb4091',
                                ],
                        ],
                    'container'        =>
                        [
                            'name'             => 'Alfresco Frontend Monitoring with SSL',
                            'parent_id'        => 1,
                            'containertype_id' => '9',
                        ],
                ],
            2 =>
                [
                    'uuid'             => '859dec83-6f14-4263-a37b-7a6cb918b7d4',
                    'description'      => 'Alfresco Application Monitoring with JMX',
                    'servicetemplates' =>
                        [
                            0  =>
                                [
                                    'id'   => '79b6214d-1bc3-446e-b05c-65492e41576d',
                                    'uuid' => '79b6214d-1bc3-446e-b05c-65492e41576d',
                                ],
                            1  =>
                                [
                                    'id'   => '59b9dab8-2070-438b-925f-e106183815ec',
                                    'uuid' => '59b9dab8-2070-438b-925f-e106183815ec',
                                ],
                            2  =>
                                [
                                    'id'   => 'bdca56b5-993b-46d8-bb30-eec1415df102',
                                    'uuid' => 'bdca56b5-993b-46d8-bb30-eec1415df102',
                                ],
                            3  =>
                                [
                                    'id'   => 'ed209128-1777-4513-9fa5-02d237871e11',
                                    'uuid' => 'ed209128-1777-4513-9fa5-02d237871e11',
                                ],
                            4  =>
                                [
                                    'id'   => 'b693825e-6702-4dce-a440-ad60f0658b98',
                                    'uuid' => 'b693825e-6702-4dce-a440-ad60f0658b98',
                                ],
                            5  =>
                                [
                                    'id'   => '99a4e5f3-f7a4-408b-8f47-9d93fe6474d1',
                                    'uuid' => '99a4e5f3-f7a4-408b-8f47-9d93fe6474d1',
                                ],
                            6  =>
                                [
                                    'id'   => '597c902f-05eb-4778-a704-17fff946409c',
                                    'uuid' => '597c902f-05eb-4778-a704-17fff946409c',
                                ],
                            7  =>
                                [
                                    'id'   => '047073c4-8193-4273-ad2f-11c9136d8fe2',
                                    'uuid' => '047073c4-8193-4273-ad2f-11c9136d8fe2',
                                ],
                            8  =>
                                [
                                    'id'   => 'cede910f-e96a-47a1-a331-a8720db91c89',
                                    'uuid' => 'cede910f-e96a-47a1-a331-a8720db91c89',
                                ],
                            9  =>
                                [
                                    'id'   => '125e915e-6014-4945-bd18-5e5b8f8ecbf1',
                                    'uuid' => '125e915e-6014-4945-bd18-5e5b8f8ecbf1',
                                ],
                            10 =>
                                [
                                    'id'   => '00762cca-2d70-41cd-b966-1c8e5c4b67ab',
                                    'uuid' => '00762cca-2d70-41cd-b966-1c8e5c4b67ab',
                                ],
                            11 =>
                                [
                                    'id'   => 'fbef3afc-97ff-4856-a327-35c08b71c633',
                                    'uuid' => 'fbef3afc-97ff-4856-a327-35c08b71c633',
                                ],
                            12 =>
                                [
                                    'id'   => '9485b87d-8c8e-4890-821a-71db5423fdb5',
                                    'uuid' => '9485b87d-8c8e-4890-821a-71db5423fdb5',
                                ],
                        ],
                    'container'        =>
                        [
                            'name'             => 'Alfresco Application Monitoring',
                            'parent_id'        => 1,
                            'containertype_id' => '9',
                        ],
                ],
        ];
        return $data;
    }
}
